@@ -82,7 +82,7 @@ class QRCodeAdmin(admin.ModelAdmin):
 
     def formfield_for_foreignkey(self, db_field, request, **kwargs):
         if db_field.name == 'department' and not request.user.is_superuser:
-            kwargs['queryset'] = request.user.departments
+            kwargs['queryset'] = request.user.departments.first()
         return super(QRCodeAdmin, self).formfield_for_foreignkey(db_field, request, **kwargs)
 
     def get_urls(self):
